@@ -343,6 +343,12 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
     else:
         com_len = comLen
     
+    commus= []
+    colorEdges = []
+    colorNodes = []
+    grayEdges = []
+    grayNodes = []
+    
     for community_index in range(com_len):
       com_DF1 = nnColor_df[nnColor_df['community_nn'] == community_index +1]
       comNodes_ori = com_DF1.node.to_list()
@@ -419,4 +425,44 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
             display(HTML(str(community_index) + 'example3.html'))
       if save_folder:
         ntc3.save_graph(save_folder+ '/{}.html'.format(community_index +1))
-          
\ No newline at end of file
+
+      # gray_color edges dataframe 
+      gray_nodes = [x for x in comNodes if x not in comNodes_ori]
+      gray_edges = []
+      color_edges = []
+      for edge in all_edges:
+        for edge1 in comEdges:
+          if edge1 == edge[:2]:
+            if len(gray_nodes)>0:
+              for node in gray_nodes:
+                if node in edge1:
+                  gray_edges.append(edge)
+                else:
+                  color_edges.append(edge)
+            else:
+              gray_edges = []
+              color_edges.append(edge)
+
+      color_nodes = comNodes_ori
+      #if len(gray_nodes)<1:
+        #gray_nodes = []
+      #set(color_edges),set(color_nodes),set(gray_edges),set(gray_nodes)
+      grayNodeDs= []
+      for node in gray_nodes:
+        degree = dict(Gdc.degree)[node]
+        nodeD = (node,degree)
+        grayNodeDs.append(nodeD)
+      colorNodeDs = []
+      for node in color_nodes:
+        degree = dict(Gdc.degree)[node]
+        nodeD = (node,degree)
+        colorNodeDs.append(nodeD)      
+    
+      
+      commus.append(community_index)
+      colorEdges.append(set(color_edges))
+      colorNodes.append(set(colorNodeDs))
+      grayEdges.append(set(gray_edges))
+      grayNodes.append(set(grayNodeDs))
+    colorGrayDF = pd.DataFrame({'commus': commus,'colorEdges':colorEdges,'colorNodes':colorNodes,'grayEdges':grayEdges,'grayNodes':grayNodes})
+    return colorGrayDF
\ No newline at end of file
