@@ -1,4 +1,4 @@
-from avn_base import countFreq
+from keypartx.basemodes.avn_base import countFreq
 import pandas as pd
 
 import leidenalg as la
@@ -101,6 +101,7 @@ def parti(all_edges,com_resolution=1):
 
 
 ## ---Color setting for community network ---##
+
 def colorsList(colorL = False):
     if colorL == False:
         colorList = ['darkred','gold','blue','orange','green','purple','lime']
